@@ -57,12 +57,14 @@
 #' pc.desc, pc.bin: PC matrix in bigmemory format
 #' Requirement: fileHMP, fileBed, and fileNum can not input at the same time
 #' @examples 
+#' \donttest{
 #' bfilePath <- file.path(system.file("extdata", "02_bfile", package = "rMVP"), "mvp")
 #' opts <- options(rMVP.OutputLog2File = FALSE)
 #' 
 #' MVP.Data(fileBed=bfilePath, out=tempfile("outfile"), ncpus=1)
 #' 
 #' options(opts)
+#' }
 MVP.Data <- function(fileMVP = NULL, fileVCF = NULL, fileHMP = NULL, fileBed = NULL, fileNum = NULL, fileMap = NULL,
                      filePhe = NULL, fileInd = NULL, fileKin = NULL, filePC = NULL, out = "mvp", sep.num = "\t",
                      auto_transpose = TRUE, sep.map = "\t", sep.phe = "\t", sep.kin = "\t", sep.pc = "\t",
@@ -221,9 +223,11 @@ MVP.Data <- function(fileMVP = NULL, fileVCF = NULL, fileHMP = NULL, fileBed = N
 #' phenotype.phe: ordered phenotype file, same taxa order with genotype file
 #' map.map: SNP information
 #' @examples 
+#' \donttest{
 #' vcfPath <- system.file("extdata", "01_vcf", "mvp.vcf", package = "rMVP")
 #' 
-#' MVP.Data.VCF2MVP(vcfPath, tempfile("outfile"))
+#' MVP.Data.VCF2MVP(vcfPath, tempfile("outfile"), threads=1)
+#' }
 #' 
 MVP.Data.VCF2MVP <- function(vcf_file, out='mvp', maxLine = 1e4, type.geno='char', threads=1, verbose=TRUE) {
     t1 <- as.numeric(Sys.time())
@@ -274,9 +278,11 @@ MVP.Data.VCF2MVP <- function(vcf_file, out='mvp', maxLine = 1e4, type.geno='char
 #' phenotype.phe: ordered phenotype file, same taxa order with genotype file
 #' map.map: SNP information
 #' @examples 
+#' \donttest{
 #' bfilePath <- file.path(system.file("extdata", "02_bfile", package = "rMVP"), "mvp")
 #' 
-#' MVP.Data.Bfile2MVP(bfilePath, tempfile("outfile"))
+#' MVP.Data.Bfile2MVP(bfilePath, tempfile("outfile"), threads=1)
+#' }
 #' 
 MVP.Data.Bfile2MVP <- function(bfile, out='mvp', maxLine=1e4, priority='speed', type.geno='char', threads=0, verbose=TRUE) {
     t1 <- as.numeric(Sys.time())
@@ -334,9 +340,11 @@ MVP.Data.Bfile2MVP <- function(bfile, out='mvp', maxLine=1e4, priority='speed',
 #' phenotype.phe: ordered phenotype file, same taxa order with genotype file
 #' map.map: SNP information
 #' @examples 
+#' \donttest{
 #' hapmapPath <- system.file("extdata", "03_hapmap", "mvp.hmp.txt", package = "rMVP")
 #' 
-#' MVP.Data.Hapmap2MVP(hapmapPath, tempfile("outfile"))
+#' MVP.Data.Hapmap2MVP(hapmapPath, tempfile("outfile"), threads=1)
+#' }
 #' 
 MVP.Data.Hapmap2MVP <- function(hmp_file, out='mvp', maxLine = 1e4, type.geno='char', threads=1, verbose=TRUE) {
     t1 <- as.numeric(Sys.time())
@@ -391,9 +399,11 @@ MVP.Data.Hapmap2MVP <- function(hmp_file, out='mvp', maxLine = 1e4, type.geno='c
 #' phenotype.phe: ordered phenotype file, same taxa order with genotype file
 #' map.map: SNP information
 #' @examples 
+#' \donttest{
 #' numericPath <- system.file("extdata", "04_numeric", "mvp.num", package = "rMVP")
 #' mapPath <- system.file("extdata", "04_numeric", "mvp.map", package = "rMVP")
 #' MVP.Data.Numeric2MVP(numericPath, mapPath, tempfile("outfile"))
+#' }
 #' 
 MVP.Data.Numeric2MVP <- function(num_file, map_file, out='mvp', maxLine=1e4, priority='speed', row_names=FALSE, col_names=FALSE, type.geno='char', auto_transpose=TRUE, verbose=TRUE) {
     t1 <- as.numeric(Sys.time())
@@ -497,6 +507,7 @@ MVP.Data.Numeric2MVP <- function(num_file, map_file, out='mvp', maxLine=1e4, pri
 #' @param map the map file
 #' @param pheno the phenotype file
 #' @param out the name of output file
+#' @param threads number of thread for transforming
 #' @param verbose whether to print the reminder
 #'
 #' @return NULL
@@ -504,15 +515,17 @@ MVP.Data.Numeric2MVP <- function(num_file, map_file, out='mvp', maxLine=1e4, pri
 #' .bed, .bim, .fam
 #' 
 #' @examples 
+#' \donttest{
 #' bigmat <- as.big.matrix(matrix(1:6, 3, 2))
 #' map <- matrix(c("rs1", "rs2", "rs3", 1, 1, 1, 10, 20, 30), 3, 3)
 #' 
-#' MVP.Data.MVP2Bfile(bigmat, map, out=tempfile("outfile"))
+#' MVP.Data.MVP2Bfile(bigmat, map, out=tempfile("outfile"), threads=1)
+#' }
 #' 
-MVP.Data.MVP2Bfile <- function(bigmat, map, pheno=NULL, out='mvp.plink', verbose=TRUE) {
+MVP.Data.MVP2Bfile <- function(bigmat, map, pheno=NULL, out='mvp.plink', threads=1, verbose=TRUE) {
     t1 <- as.numeric(Sys.time())
     # write bed file
-    write_bfile(bigmat@address, out, verbose = verbose)
+    write_bfile(bigmat@address, out, threads=threads, verbose = verbose)
     
     # write fam
     #  1. Family ID ('FID')
@@ -698,9 +711,11 @@ MVP.Data.Map <- function(map, out='mvp', cols=1:5, header=TRUE, sep='\t', verbos
 #' <out>.pc.bin
 #' <out>.pc.desc
 #' @examples
+#' \donttest{
 #' geno <- file.path(system.file("extdata", "06_mvp-impute", package = "rMVP"), "mvp.imp")
 #' 
-#' MVP.Data.PC(TRUE, mvp_prefix=geno, out=tempfile("outfile"))
+#' MVP.Data.PC(TRUE, mvp_prefix=geno, out=tempfile("outfile"), cpus=1)
+#' }
 #' 
 MVP.Data.PC <- function(
     filePC=TRUE, 
@@ -765,9 +780,11 @@ MVP.Data.PC <- function(
 #' <out>.kin.bin
 #' <out>.kin.desc
 #' @examples
+#' \donttest{
 #' geno <- file.path(system.file("extdata", "06_mvp-impute", package = "rMVP"), "mvp.imp")
 #' 
-#' MVP.Data.Kin(TRUE, mvp_prefix=geno, out=tempfile("outfile"))
+#' MVP.Data.Kin(TRUE, mvp_prefix=geno, out=tempfile("outfile"), cpus=1)
+#' }
 #' 
 MVP.Data.Kin <- function(
     fileKin=TRUE, 
